Exception: Rika::TikaLoadError
- Inherits:
-
RuntimeError
- Object
- RuntimeError
- Rika::TikaLoadError
- Defined in:
- lib/rika/tika_loader.rb
Overview
This error class reports the inability to load the Tika jar file.
This error class reports the inability to load the Tika jar file.